@@ -4,7 +4,7 @@ from typing import List, Dict, Tuple
 
 from pandas import DataFrame
 from previsionio import metrics
-from previsionio.experiment_config import ColumnConfig, DataType, TrainingConfig, TypeProblem
+from previsionio.experiment_config import ColumnConfig, DataType, Provider, TrainingConfig, TypeProblem
 import requests
 
 from . import client
@@ -23,6 +23,7 @@ from .text_similarity import (DescriptionsColumnConfig, ListModelsParameters, Qu
 from .experiment import Experiment
 from .experiment_deployment import ExperimentDeployment
 from .model import Model
+from .pipeline import PipelineScheduledRun
 
 
 class ProjectColor(Enum):
@@ -384,14 +385,14 @@ class Project(ApiResource, UniqueResourceMixin):
         """
         return S3Connector._new(self._id, name, username=username, password=password)
 
-    def create_gcp_connector(self, name: str, googleCredentials: str):
+    def create_gcp_connector(self, name: str, googleCredentials: Dict):
         """ A connector to interact with a distant source of data (and
         easily get data snapshots using an associated :class:`.DataSource`
         resource).
 
         Args:
             name (str): Name of the connector
-            googleCredentials(str): google credentials
+            googleCredentials(dict): google credentials
         Returns:
             :class:`.GCPConnector`: The registered connector object in the current project.
         """
@@ -508,6 +509,25 @@ class Project(ApiResource, UniqueResourceMixin):
         """
         return Exporter.list(self._id, all=all)
 
+    def list_pipeline_scheduled_runs(self, all: bool = False):
+        """ List all the available pipeline scheduled runs in the current active project.
+
+        .. warning::
+
+            Contrary to the parent ``list()`` function, this method
+            returns actual :class:`.Exporter` objects rather than
+            plain dictionaries with the corresponding data.
+
+        Args:
+            all (boolean, optional): Whether to force the SDK to load all items of
+                the given type (by calling the paginated API several times). Else,
+                the query will only return the first page of result.
+
+        Returns:
+            list(:class:`.PipelineScheduledRun`): Fetched dataset objects
+        """
+        return PipelineScheduledRun.list(self._id, all=all)
+
     def fit_regression(
         self,
         experiment_name: str,
@@ -539,7 +559,7 @@ class Project(ApiResource, UniqueResourceMixin):
         Returns:
             :class:`.supervised.Supervised`: Newly created Supervised experiment version object
         """
-        experiment = Experiment.new(self._id, 'prevision-auto-ml', experiment_name, DataType.Tabular,
+        experiment = Experiment.new(self._id, Provider.Prevision, experiment_name, DataType.Tabular,
                                     TypeProblem.Regression)
         return Supervised._fit(
             experiment.id,
@@ -582,7 +602,7 @@ class Project(ApiResource, UniqueResourceMixin):
         Returns:
             :class:`.supervised.Supervised`: Newly created Supervised experiment version object
         """
-        experiment = Experiment.new(self._id, 'prevision-auto-ml', experiment_name, DataType.Tabular,
+        experiment = Experiment.new(self._id, Provider.Prevision, experiment_name, DataType.Tabular,
                                     TypeProblem.Classification)
         return Supervised._fit(
             experiment.id,
@@ -625,7 +645,7 @@ class Project(ApiResource, UniqueResourceMixin):
         Returns:
             :class:`.supervised.Supervised`: Newly created Supervised experiment version object
         """
-        experiment = Experiment.new(self._id, 'prevision-auto-ml', experiment_name, DataType.Tabular,
+        experiment = Experiment.new(self._id, Provider.Prevision, experiment_name, DataType.Tabular,
                                     TypeProblem.MultiClassification)
         return Supervised._fit(
             experiment.id,
@@ -671,7 +691,7 @@ class Project(ApiResource, UniqueResourceMixin):
         Returns:
             :class:`.supervised.Supervised`: Newly created Supervised experiment version object
         """
-        experiment = Experiment.new(self._id, 'prevision-auto-ml', experiment_name, DataType.Images,
+        experiment = Experiment.new(self._id, Provider.Prevision, experiment_name, DataType.Images,
                                     TypeProblem.Regression)
         dataset = (dataset, dataset_images)
         return Supervised._fit(
@@ -718,7 +738,7 @@ class Project(ApiResource, UniqueResourceMixin):
         Returns:
             :class:`.supervised.Supervised`: Newly created Supervised experiment version object
         """
-        experiment = Experiment.new(self._id, 'prevision-auto-ml', experiment_name, DataType.Images,
+        experiment = Experiment.new(self._id, Provider.Prevision, experiment_name, DataType.Images,
                                     TypeProblem.Classification)
         dataset = (dataset, dataset_images)
         return Supervised._fit(
@@ -765,7 +785,7 @@ class Project(ApiResource, UniqueResourceMixin):
         Returns:
             :class:`.supervised.Supervised`: Newly created Supervised experiment version object
         """
-        experiment = Experiment.new(self._id, 'prevision-auto-ml', experiment_name, DataType.Images,
+        experiment = Experiment.new(self._id, Provider.Prevision, experiment_name, DataType.Images,
                                     TypeProblem.MultiClassification)
         dataset = (dataset, dataset_images)
         return Supervised._fit(
@@ -812,7 +832,7 @@ class Project(ApiResource, UniqueResourceMixin):
         Returns:
             :class:`.timeseries.TimeSeries`: Newly created TimeSeries experiment version object
         """
-        experiment = Experiment.new(self._id, 'prevision-auto-ml', experiment_name, DataType.TimeSeries,
+        experiment = Experiment.new(self._id, Provider.Prevision, experiment_name, DataType.TimeSeries,
                                     TypeProblem.Regression)
         return TimeSeries._fit(
             experiment.id,
@@ -864,7 +884,7 @@ class Project(ApiResource, UniqueResourceMixin):
         Returns:
             :class:`.text_similarity.TextSimilarity`: Newly created TextSimilarity experiment version object
         """
-        experiment = Experiment.new(self._id, 'prevision-auto-ml', experiment_name, DataType.Tabular,
+        experiment = Experiment.new(self._id, Provider.Prevision, experiment_name, DataType.Tabular,
                                     TypeProblem.TextSimilarity)
         return TextSimilarity._fit(
             experiment.id,
@@ -911,7 +931,7 @@ class Project(ApiResource, UniqueResourceMixin):
         """
         if len(external_models) == 0:
             raise PrevisionException('You must provide at least one external model')
-        experiment = Experiment.new(self._id, 'external', experiment_name, DataType.Tabular,
+        experiment = Experiment.new(self._id, Provider.External, experiment_name, DataType.Tabular,
                                     TypeProblem.Regression)
         return ExternalExperimentVersion._fit(
             experiment.id,
@@ -956,7 +976,7 @@ class Project(ApiResource, UniqueResourceMixin):
         """
         if len(external_models) == 0:
             raise PrevisionException('You must provide at least one external model')
-        experiment = Experiment.new(self._id, 'external', experiment_name, DataType.Tabular,
+        experiment = Experiment.new(self._id, Provider.External, experiment_name, DataType.Tabular,
                                     TypeProblem.Classification)
         return ExternalExperimentVersion._fit(
             experiment.id,
@@ -1001,7 +1021,7 @@ class Project(ApiResource, UniqueResourceMixin):
         """
         if len(external_models) == 0:
             raise PrevisionException('You must provide at least one external model')
-        experiment = Experiment.new(self._id, 'external', experiment_name, DataType.Tabular,
+        experiment = Experiment.new(self._id, Provider.External, experiment_name, DataType.Tabular,
                                     TypeProblem.MultiClassification)
         return ExternalExperimentVersion._fit(
             experiment.id,
@@ -1030,6 +1050,7 @@ class Project(ApiResource, UniqueResourceMixin):
         name: str,
         main_model: Model,
         challenger_model: Model = None,
+        type_violation_policy: str = 'best_effort',
         access_type: str = 'public',
     ) -> ExperimentDeployment:
         """ Create a new experiment deployment in the current project.
@@ -1039,6 +1060,7 @@ class Project(ApiResource, UniqueResourceMixin):
             main_model (:class:`.Model`): main model
             challenger_model (:class:`.Model`, optional): challenger model (main and challenger
                 models should come from the same experiment)
+            type_violation_policy (str, optional): best_effort/ strict
             access_type (str, optional): public/ fine_grained/ private
         Returns:
             :class:`.ExperimentDeployment`: Fetched experiment deployment object
@@ -1048,6 +1070,7 @@ class Project(ApiResource, UniqueResourceMixin):
             name,
             main_model,
             challenger_model=challenger_model,
+            type_violation_policy=type_violation_policy,
             access_type=access_type,
         )
 
